==> nextcloud-app-contacts-7.1.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/id.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detil",
    "All contacts" : "Semua kontak",
    "Contacts" : "Kontak",
    "A contacts app for Nextcloud" : "Sebuah aplikasi kontak untuk Nextcloud",
    "Rename" : "Ubah nama",
    "Send email" : "Kirim surel",
    "Delete" : "Hapus",
    "Copy link" : "Salin tautan",
    "Download" : "Unduh",
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "can edit" : "dapat menyunting",
    "Add" : "Masukkan",
    "First name" : "Nama depan",
    "Last name" : "Nama belakang",
    "Display name" : "Nama tampilan",
    "Last modified" : "Terakhir diubah",
    "Password protection" : "Password protection",
    "Save" : "Simpan",
    "Description" : "Deskrisi",
    "Settings" : "Settings",
    "Cancel" : "Membatalkan",
    "Invalid image" : "Gambar tidak sah",
    "Name" : "Nama",
    "Title" : "Judul",
    "Search contacts …" : "Cari kontak ...",
    "No results" : "Tidak ada hasil",
    "Pending" : "Tunggu",
    "None" : "Tidak ada",
    "New contact" : "Kontak baru",
    "Close" : "Tutup",
    "Import" : "Impor",
    "Not grouped" : "Tidak dikelompokkan",
    "User" : "Pengguna",
    "Group" : "Grup",
    "Email" : "Surel",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Detailed name" : "Nama lengkap",
    "Additional names" : "Nama tambahan",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Nama panggilan",
    "Notes" : "Catatan",
    "Website" : "Situs Web",
    "Location" : "Lokasi",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Depan",
    "Work" : "Kantor",
    "Other" : "Lainnya",
    "Address" : "Alamat",
    "Post office box" : "PO BOX",
    "City" : "Kota",
    "State or province" : "Provinsi",
    "Postal code" : "Kode pos",
    "Country" : "Negara",
    "Birthday" : "Tanggal lahir",
    "Anniversary" : "Ulang tahun",
    "Date of death" : "Tanggal kematian",
    "Instant messaging" : "Pesan Instan",
    "Phone" : "Telpon",
    "Mobile" : "Ponsel",
    "Fax" : "Fax",
    "Fax home" : "Fax rumah",
    "Fax work" : "Fax kerja",
    "Pager" : "Pager",
    "Voice" : "Suara",
    "Social network" : "Media sosial",
    "Unknown" : "Tidak diketahui"
},
"nplurals=1; plural=0;");

==> nextcloud-app-contacts-7.2.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/contacts/l10n/id.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Detil",
    "All contacts" : "Semua kontak",
    "Contacts" : "Kontak",
    "A contacts app for Nextcloud" : "Sebuah aplikasi kontak untuk Nextcloud",
    "Rename" : "Ubah nama",
    "Send email" : "Kirim email",
    "Delete" : "Hapus",
    "Copy link" : "Salin tautan",
    "Download" : "Unduh",
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "can edit" : "dapat menyunting",
    "Add" : "Masukkan",
    "First name" : "Nama depan",
    "Last name" : "Nama belakang",
    "Display name" : "Nama tampilan",
    "Last modified" : "Terakhir diubah",
    "Password protection" : "Password protection",
    "Save" : "Simpan",
    "Description" : "Deskrisi",
    "Settings" : "Settings",
    "Cancel" : "Membatalkan",
    "Invalid image" : "Gambar tidak sah",
    "Name" : "Nama",
    "Title" : "Judul",
    "Search contacts …" : "Cari kontak ...",
    "No results" : "Tidak ada hasil",
    "Pending" : "Tunggu",
    "None" : "Tidak ada",
    "New contact" : "Kontak baru",
    "Close" : "Tutup",
    "Import" : "Impor",
    "Not grouped" : "Tidak dikelompokkan",
    "User" : "Pengguna",
    "Group" : "Grup",
    "Email" : "Email",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Detailed name" : "Nama lengkap",
    "Additional names" : "Nama tambahan",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Nama panggilan",
    "Notes" : "Catatan",
    "Website" : "Situs Web",
    "Location" : "Lokasi",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Depan",
    "Work" : "Kantor",
    "Other" : "Lainnya",
    "Address" : "Alamat",
    "Post office box" : "PO BOX",
    "City" : "Kota",
    "State or province" : "Provinsi",
    "Postal code" : "Kode pos",
    "Country" : "Negara",
    "Birthday" : "Tanggal lahir",
    "Anniversary" : "Ulang tahun",
    "Date of death" : "Tanggal kematian",
    "Instant messaging" : "Pesan Instan",
    "Phone" : "Telpon",
    "Mobile" : "Ponsel",
    "Fax" : "Fax",
    "Fax home" : "Fax rumah",
    "Fax work" : "Fax kerja",
    "Pager" : "Pager",
    "Voice" : "Suara",
    "Social network" : "Media sosial",
    "Unknown" : "Tidak diketahui"
},
"nplurals=1; plural=0;");
